summaryrefslogtreecommitdiff
path: root/engine/field_select_screen.asm
diff options
context:
space:
mode:
Diffstat (limited to 'engine/field_select_screen.asm')
-rw-r--r--engine/field_select_screen.asm6
1 files changed, 3 insertions, 3 deletions
diff --git a/engine/field_select_screen.asm b/engine/field_select_screen.asm
index 0941547..f500d01 100644
--- a/engine/field_select_screen.asm
+++ b/engine/field_select_screen.asm
@@ -95,14 +95,14 @@ ExitFieldSelectScreen: ; 0xd774
ld [wCurrentStage], a
pop af
xor a
- ld [wd7c2], a
+ ld [wSavedGame], a
ld hl, wPartyMons
ld de, sSaveGame
ld bc, $04c3
call SaveData
xor a
- ld [wd7c1], a
- ; Start a round of Pinball! Yayy
+ ld [wLoadingSavedGame], a
+ ; Start a game of Pinball
ld a, SCREEN_PINBALL_GAME
ld [wCurrentScreen], a
xor a